<?php

namespace Assetdocs\Facilities\Policies;

use Litepie\User\Contracts\UserPolicy;
use Assetdocs\Facilities\Models\Facility;

class FacilityPolicy
{

    /**
     * Determine if the given user can view the facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function view(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facilities.facility.view') && $user->isAdmin()) {
            return true;
        }

        return $facility->user_id == user_id() && $facility->user_type == user_type();
    }

    /**
     * Determine if the given user can create a facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('facilities.facility.create');
    }

    /**
     * Determine if the given user can update the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function update(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facilities.facility.edit') && $user->isAdmin()) {
            return true;
        }

        return $facility->user_id == user_id() && $facility->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Facility $facility)
    {
        return $facility->user_id == user_id() && $facility->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facilities.facility.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facilities.facility.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
